@@ -3,7 +3,7 @@ package HTTP::Config;
 use strict;
 use warnings;
 
-our $VERSION = '6.27';
+our $VERSION = '6.28';
 
 use URI;
 
@@ -155,8 +155,12 @@ my %MATCH = (
     m_header__ => sub {
         my($v, $k, $uri, $request, $response) = @_;
         return unless $request;
-        return 1 if $request->header($k) eq $v;
-        return 1 if $response && $response->header($k) eq $v;
+        my $req_header = $request->header($k);
+        return 1 if defined($req_header) && $req_header eq $v;
+        if ($response) {
+            my $res_header = $response->header($k);
+            return 1 if defined($res_header) && $res_header eq $v;
+        }
         return 0;
     },
     m_response_attr__ => sub {
@@ -245,7 +249,7 @@ HTTP::Config - Configuration for request and response objects
 
 =head1 VERSION
 
-version 6.27
+version 6.28
 
 =head1 SYNOPSIS
 
